@@ -1,14 +1,14 @@
 //! Module containing all the necessary code to request `https://127.0.0.1:2999/liveclientdata/` endpoints.
 //! The official documentation can be found at [https://developer.riotgames.com/docs/lol#game-client-api]
 
+use crate::api;
+use crate::model::{Abilities, ActivePlayer, AllGameData, Events, FullRunes, GameData, Player};
 use reqwest::{Certificate, IntoUrl};
 use serde::Deserialize;
-use crate::model::{Abilities, ActivePlayer, AllGameData, Events, FullRunes, GameData, Player};
 use thiserror::Error;
-use crate::api;
 
 pub struct GameClient {
-    client: reqwest::Client
+    client: reqwest::Client,
 }
 
 /// Get the root certificate that is used to sign the SSL certificates.
@@ -20,7 +20,7 @@ pub fn get_riot_root_certificate() -> Certificate {
 
 #[derive(Debug, Error)]
 pub enum QueryError {
-    #[error("Failed to query the API. Is the game running ?")]
+    #[error("Failed to query the API. Is the game running ? '{}'", _0)]
     Reqwest(#[from] reqwest::Error), // An error of this type may suggests that the API specs as been updated and the crate is out-of-date. Please fill an issue !
 }
 
@@ -41,12 +41,17 @@ impl GameClient {
     /// Otherwise, use `GameClient::new`
     pub fn _from_certificate(certificate: Certificate) -> Result<Self, QueryError> {
         Ok(GameClient {
-            client: reqwest::ClientBuilder::new().add_root_certificate(certificate).build()?
+            client: reqwest::ClientBuilder::new()
+                .add_root_certificate(certificate)
+                .build()?,
         })
     }
 
     /// Query the endpoint and automagically deserialize the json into the desired type
-    async fn get_data<T: for<'de> Deserialize<'de>, U: IntoUrl>(&self, endpoint: U) -> Result<T, QueryError> {
+    async fn get_data<T: for<'de> Deserialize<'de>, U: IntoUrl>(
+        &self,
+        endpoint: U,
+    ) -> Result<T, QueryError> {
         let data = self.client.get(endpoint).send().await?.json::<T>().await?;
         Ok(data)
     }
@@ -95,12 +100,11 @@ impl GameClient {
     pub async fn game_stats(&self) -> Result<GameData, QueryError> {
         self.get_data(api!("gamestats")).await
     }
-
 }
 
 #[macro_export]
 macro_rules! api {
     ($endpoint:expr) => {
         concat!("https://127.0.0.1:2999/liveclientdata/", $endpoint)
-    }
-}
\ No newline at end of file
+    };
+}
